==> 0.0.2a.zip: menagerie_cookbook/shared/src/commonMain/kotlin/App.kt <==
import androidx.compose.animation.ExperimentalSharedTransitionApi
import androidx.compose.animation.SharedTransitionLayout
import androidx.compose.foundation.isSystemInDarkTheme
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.width
import androidx.compose.material3.Button
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateListOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import details.RecipeDetails
import model.TagType
import recipeslist.RecipesListScreen
import sensor.SensorManager
import ui.theme.MainTheme
import view.BookShelf
import view.FilterCard
import view.HomeScreen
import view.InputFieldState
import view.getFilteredRecipeList
import view.getRecipeList


enum class Theme {
    Auto,
    Light,
    Dark
}

enum class RecipeAppScreen {
    List, Details,
}

@OptIn(ExperimentalSharedTransitionApi::class)
@Composable
fun App(sensorManager: SensorManager?, isLarge: Boolean = false) {

    val navController = rememberNavController()
    var theme by remember { mutableStateOf(Theme.Dark) }

    val onThemeToggle = {
        theme = when (theme) {
            Theme.Auto -> Theme.Light
            Theme.Light -> Theme.Dark
            Theme.Dark -> Theme.Auto
        }
    }
    val isDarkTheme: Boolean? = when (theme) {
        Theme.Dark -> true
        Theme.Light -> false
        Theme.Auto -> null
    }

    MainTheme(isDarkTheme ?: isSystemInDarkTheme()) {

        var show by remember { mutableStateOf(false) }
        var searchBar by remember { mutableStateOf(false) }
        var search by remember { mutableStateOf("") }
        val tags = remember { mutableStateListOf<String>() }
        val recipeTags by remember { mutableStateOf(mutableMapOf<String, TagType>()) }
        var book by remember { mutableStateOf("") }

        for (recipe in getRecipeList()) {
            for (tag in recipe.tags) {
                if (!recipeTags.contains(tag.key))
                    recipeTags[tag.key] = tag.value
            }
        }

        if (show) {
            FilterCard(recipeTags.keys.toList()) {
                tags.removeAll(tags)
                tags.addAll(it)
                show = false
            }
        }

        val filteredItems = getFilteredRecipeList(tags, search, book)
        var currentRecipe = getRecipeList().first()

        if (filteredItems.isNotEmpty())
            currentRecipe = filteredItems.first()

        Scaffold {
            Column {
                if (searchBar) {
                    Row {

                        if(isLarge)
                        {
                            Button(onClick = {navController.navigateUp()}){
                                Text("Back")
                            }
                        }

                        Button(
                            onClick = {
                                show = true
                            },
                        ) {
                            Text(text = "Filter")
                        }
                        InputFieldState(
                            value = search,
                            label = "Search",
                            modifier = Modifier
                                .width(if(isLarge) 400.dp else 200.dp)
                        ) {
                            search = it
                        }

                        Spacer(modifier = Modifier.weight(1f))

                        Button(
                            onClick = {onThemeToggle.invoke()}
                        ){
                            Text(text = theme.name)
                        }

                    }
                }

                SharedTransitionLayout {
                    NavHost(
                        navController = navController,
                        startDestination = "Home",
                        modifier = Modifier.fillMaxSize()
                    ) {
                        composable(route = "Home")
                        {
                            HomeScreen(
                                isLarge = isLarge,
                                onClick = {
                                    searchBar = false
                                    navController.navigate("BookShelf")
                                }
                            )
                        }
                        composable(route = "BookShelf")
                        {
                            BookShelf(
                                isLarge = isLarge,
                                tags = recipeTags,
                                onClick = { lockedTag ->
                                    book = lockedTag
                                    searchBar = true
                                    navController.navigate(RecipeAppScreen.List.name)

                                }
                            )
                        }
                        composable(
                            route = RecipeAppScreen.List.name
                            ) {
                            RecipesListScreen(
                                isLarge = isLarge,
                                items = filteredItems,
                                onClick = { recipe ->
                                    searchBar = false
                                    currentRecipe = recipe
                                    navController.navigate(RecipeAppScreen.Details.name)
                                })
                        }
                        composable(route = RecipeAppScreen.Details.name) {
                            RecipeDetails(
                                isLarge = isLarge,
                                sensorManager = sensorManager,
                                recipe = currentRecipe,
                                goBack = {
                                    searchBar = true
                                    navController.popBackStack()
                                })
                        }
                    }
                }
            }
        }
    }
}

==> 0.1.0a.zip: menagerie_cookbook/shared/src/commonMain/kotlin/App.kt <==
import androidx.compose.animation.ExperimentalSharedTransitionApi
import androidx.compose.animation.SharedTransitionLayout
import androidx.compose.foundation.isSystemInDarkTheme
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.lazy.grid.GridCells
import androidx.compose.foundation.lazy.grid.LazyVerticalGrid
import androidx.compose.foundation.lazy.grid.rememberLazyGridState
import androidx.compose.material3.Button
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateListOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import details.RecipeDetails
import model.TagType
import recipeslist.RecipesListScreen
import sensor.SensorManager
import ui.theme.MainTheme
import view.BookShelf
import view.FilterCard
import view.HomeScreen
import view.InputFieldState
import view.getFilteredRecipeList
import view.getRecipeList


enum class Theme {
    Auto,
    Light,
    Dark
}

enum class RecipeAppScreen {
    List, Details,
}

@OptIn(ExperimentalSharedTransitionApi::class)
@Composable
fun App(sensorManager: SensorManager?, isLarge: Boolean = false, isWebApp: Boolean = false) {

    val navController = rememberNavController()
    var theme by remember { mutableStateOf(Theme.Dark) }

    val onThemeToggle = {
        theme = when (theme) {
            Theme.Auto -> Theme.Light
            Theme.Light -> Theme.Dark
            Theme.Dark -> Theme.Auto
        }
    }
    val isDarkTheme: Boolean? = when (theme) {
        Theme.Dark -> true
        Theme.Light -> false
        Theme.Auto -> null
    }

    MainTheme(isDarkTheme ?: isSystemInDarkTheme()) {

        var show by remember { mutableStateOf(false) }
        var searchBar by remember { mutableStateOf(false) }
        var search by remember { mutableStateOf("") }
        val tags = remember { mutableStateListOf<String>() }
        val recipeTags by remember { mutableStateOf(mutableMapOf<String, TagType>()) }
        var book by remember { mutableStateOf("") }

        for (recipe in getRecipeList()) {
            for (tag in recipe.tags) {
                if (!recipeTags.contains(tag.key))
                    recipeTags[tag.key] = tag.value
            }
        }

        if (show) {
            FilterCard(
                recipeTags = recipeTags.keys.toList(),
                activeTags = tags
            ) {
                for(item in it)
                    if(tags.contains(item).not())
                        tags.add(item)

                show = false
            }
        }

        val filteredItems = getFilteredRecipeList(tags, search, book)
        var currentRecipe = getRecipeList().first()

        if (filteredItems.isNotEmpty())
            currentRecipe = filteredItems.first()

        Scaffold {
            Column {
                if(searchBar && isLarge) {
                    Column {
                        if (isLarge || isWebApp) {
                            Button(onClick = { navController.navigateUp() }) {
                                Text("Back")
                            }
                        }
                    }
                }
                if (searchBar) {
                        Row {
                            Button(
                                onClick = {
                                    show = true
                                },
                            ) {
                                Text(text = "Filter")
                            }
                            InputFieldState(
                                value = search,
                                label = "Search",
                                modifier = Modifier
                                    .width(if (isLarge) 400.dp else 200.dp)
                            ) {
                                search = it
                            }

                            Spacer(modifier = Modifier.weight(1f))

                            Button(
                                onClick = { onThemeToggle.invoke() }
                            ) {
                                Text(text = theme.name)
                            }
                        }
                        val listState = rememberLazyGridState()
                        LazyVerticalGrid(
                            state = listState, columns = GridCells.Fixed(if (isLarge) 10 else 4)
                        )
                        {
                            items(tags.size) {
                                Button(onClick = { tags.remove(tags[it]) }) {
                                    Text(text = tags[it])
                                }
                            }
                        }

                    }

                SharedTransitionLayout {
                    NavHost(
                        navController = navController,
                        startDestination = "Home",
                        modifier = Modifier.fillMaxSize()
                    ) {
                        composable(route = "Home")
                        {
                            searchBar = false
                            HomeScreen(
                                isLarge = isLarge,
                                onClick = {
                                    if(isWebApp)
                                        navController.navigate(RecipeAppScreen.List.name)
                                    else
                                        navController.navigate("BookShelf")
                                }
                            )
                        }
                        composable(route = "BookShelf")
                        {
                            searchBar = false
                            BookShelf(
                                isLarge = isLarge,
                                tags = recipeTags,
                                onClick = { lockedTag ->
                                    book = lockedTag
                                    navController.navigate(RecipeAppScreen.List.name)

                                }
                            )
                        }
                        composable(
                            route = RecipeAppScreen.List.name
                        ) {
                            if(isWebApp.not())
                                searchBar = true

                            RecipesListScreen(
                                isLarge = isLarge,
                                items = filteredItems,
                                onClick = { recipe ->
                                    currentRecipe = recipe
                                    navController.navigate(RecipeAppScreen.Details.name)
                                })
                        }
                        composable(route = RecipeAppScreen.Details.name) {
                            searchBar = false
                            RecipeDetails(
                                isLarge = isLarge,
                                isWebApp = isWebApp,
                                sensorManager = sensorManager,
                                recipe = currentRecipe,
                                goBack = {
                                    navController.popBackStack()
                                })
                        }
                    }
                }
            }
        }
    }
}
